
/*
  Copyright 1995 The University of Rhode Island and The Massachusetts
  Institute of Technology

  Portions of this software were developed by the Graduate School of
  Oceanography (GSO) at the University of Rhode Island (URI) in collaboration
  with The Massachusetts Institute of Technology (MIT).

  Access and use of this software shall impose the following obligations and
  understandings on the user. The user is granted the right, without any fee
  or cost, to use, copy, modify, alter, enhance and distribute this software,
  and any derivative works thereof, and its supporting documentation for any
  purpose whatsoever, provided that this entire notice appears in all copies
  of the software, derivative works and supporting documentation.  Further,
  the user agrees to credit URI/MIT in any publications that result from the
  use of this software or in any product that includes this software. The
  names URI, MIT and/or GSO, however, may not be used in any advertising or
  publicity to endorse or promote any products or commercial entity unless
  specific written permission is obtained from URI/MIT. The user also
  understands that URI/MIT is not obligated to provide the user with any
  support, consulting, training or assistance of any kind with regard to the
  use, operation and performance of this software nor to provide the user
  with any updates, revisions, new versions or "bug fixes".

  THIS SOFTWARE IS PROVIDED BY URI/MIT "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
  EVENT SHALL URI/MIT BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
  DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
  PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTUOUS
  ACTION, ARISING OUT OF OR IN CONNECTION WITH THE ACCESS, USE OR PERFORMANCE
  OF THIS SOFTWARE.
*/

// Convert to CDF server
//
// csf 4/19/96

// Implementation for the class TestStructure. See TestByte.cc
//
// jhrg 1/12/95

// $Log: CDFStructure.cc,v $
// Revision 1.1  1996/06/10 20:33:57  jimg
// Added.
//
// Revision 1.6  1995/07/09  21:29:20  jimg
// Added copyright notice.
//
// Revision 1.5  1995/05/10  17:35:34  jimg
// Removed the header file `Test.h' from the Test*.cc implementation files.
//
// Revision 1.4  1995/03/04  14:38:10  jimg
// Modified these so that they fit with the changes in the DAP classes.
//
// Revision 1.3  1995/02/10  02:33:48  jimg
// Modified Test<class>.h and .cc so that they used to new definitions of
// read_val().
// Modified the classes read() so that they are more in line with the
// class library's intended use in a real subclass set.
//
// Revision 1.2  1995/01/19  21:59:05  jimg
// Added read_val from dummy_read.cc to the sample set of sub-class
// implementations.
// Changed the declaration of readVal in BaseType so that it names the
// mfunc read_val (to be consistant with the other mfunc names).
// Removed the unnecessary duplicate declaration of the abstract virtual
// mfuncs read and (now) read_val from the classes Byte, ... Grid. The
// declaration in BaseType is sufficient along with the decl and definition
// in the *.cc,h files which contain the subclasses for Byte, ..., Grid.
//
// Revision 1.1  1995/01/19  20:20:56  jimg
// Created as an example of subclassing the class hierarchy rooted at
// BaseType.
//

#ifdef _GNUG_
#pragma implementation
#endif

#include "CDFStructure.h"
#ifdef NEVER
#include "cdf.h"

String cdfstructure = "CDFStructure";
#endif

Structure *
NewStructure(const String &n)
{
    return new CDFStructure(n);
}

BaseType *
CDFStructure::ptr_duplicate()
{
    return new CDFStructure(*this);
}

CDFStructure::CDFStructure(const String &n) : Structure(n)
{
}

CDFStructure::~CDFStructure()
{
}

// For this `Test' class, run the read mfunc for each of variables which
// comprise the structure. 
//
// To use this mfunc you must make sure that the instnace of TestStructure
// actually has fields defined (using add_var()).
//
// NB: In general it won't work to just pass the constraint expression down
// to the variable's read mfunc; you will have to parse that c expr and send
// only the relavent parts.

bool
CDFStructure::read(String dataset, String var_name, String constraint)
{

  cout << "CDFStructure::read(String, String, String): UnImplemented!" << endl;

    for (Pix p = first_var(); p; next_var(p)) {
	if (!var(p)->read(dataset, var(p)->get_var_name(), constraint))
	    return false;
    }

    return true;
}
