
/*
  Copyright 1995 The University of Rhode Island and The Massachusetts
  Institute of Technology

  Portions of this software were developed by the Graduate School of
  Oceanography (GSO) at the University of Rhode Island (URI) in collaboration
  with The Massachusetts Institute of Technology (MIT).

  Access and use of this software shall impose the following obligations and
  understandings on the user. The user is granted the right, without any fee
  or cost, to use, copy, modify, alter, enhance and distribute this software,
  and any derivative works thereof, and its supporting documentation for any
  purpose whatsoever, provided that this entire notice appears in all copies
  of the software, derivative works and supporting documentation.  Further,
  the user agrees to credit URI/MIT in any publications that result from the
  use of this software or in any product that includes this software. The
  names URI, MIT and/or GSO, however, may not be used in any advertising or
  publicity to endorse or promote any products or commercial entity unless
  specific written permission is obtained from URI/MIT. The user also
  understands that URI/MIT is not obligated to provide the user with any
  support, consulting, training or assistance of any kind with regard to the
  use, operation and performance of this software nor to provide the user
  with any updates, revisions, new versions or "bug fixes".

  THIS SOFTWARE IS PROVIDED BY URI/MIT "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
  EVENT SHALL URI/MIT BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
  DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
  PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTUOUS
  ACTION, ARISING OUT OF OR IN CONNECTION WITH THE ACCESS, USE OR PERFORMANCE
  OF THIS SOFTWARE.
*/

// This is the main CGI program which extracts DDS class descriptors from a
// netCDF data file. In addition, the descriptors from an external file (if 
// exist, with the same name as the netCDF file and extension of .dds)  
// are extracted and added to the in-memory DDS table before it is sent 
// over the network to the client side. 
//
// ReZa 10/20/94

// $Log: cdf_dds.cc,v $
// Revision 1.1  1996/06/10 20:34:12  jimg
// Added.
//
// Revision 1.6  1995/07/09  21:33:58  jimg
// Added copyright notice.
//
// Revision 1.5  1995/06/27  21:07:30  jimg
// Fixed up the error reporting. Added/corrected some comments.
//
// Revision 1.4  1995/06/23  15:33:25  jimg
// Modified these so that they are simple UNIX filters which write a MIME
// docement onto standard output.
//
// Revision 1.3  1995/03/16  16:56:52  reza
// Updated for the new DAP. All the read_val mfunc. and their memory management
// are now moved to their parent class.
// Data transfers are now in binary while DAS and DDS are still sent in ASCII.
//
// Revision 1.2  1994/10/28  15:12:15  reza
// Added the comments
//
// Revision 1.1  1994/10/28  14:34:02  reza
// First version
//

static char rcsid[]={"$Id: cdf_dds.cc,v 1.1 1996/06/10 20:34:12 jimg Exp $"};

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include <iostream.h>

#include "DDS.h"
#include "netio.h"

int 
main(int argc, char * argv[])
{
    static char ExtFile[128], Msgt[255];
    extern bool read_descriptors(DDS &dds, char *filename);
    DDS dds;

    set_mime_text();

    if(argc < 2) {
	ErrMsgT("cdf_dds: Usage <datafile>");
        exit(1);
    }

    // Read the netCDF file dataset descriptor in memory

    if(!read_descriptors(dds, argv[1])){
	  ErrMsgT("cdf_dds: Could not read the dataset descriptor information");
	  exit(1);
    }

    // if external descriptor file exist, read it ...
    // This file must be in the same directory that 
    // the netCDF file is located. Its name must be the
    // netCDF file name with the addition of .dds

    sprintf (ExtFile, "%s.dds", argv[1]); 
    FILE *in = fopen(ExtFile, "r");
 
    if (in) {
	int status = dds.parse(in);

	if(!status) {
	    sprintf (Msgt, "cdf_dds:Parse error in external file %s", ExtFile);
	    ErrMsgT(Msgt);
	    exit(1);
	}
	fclose(in);
    }

    // Forward the DDS class over the network to the client side

    dds.print();
}
